@@ -170,20 +170,16 @@
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 148 "grammar.y"
+#line 154 "grammar.y"
 {
-    
-    void*           sized_string;
-    char*           c_string;
-    size_t          integer;
-    void*           string;
-    void*           term;
-    void*           tag;
-    void*           meta;
-
+  SIZED_STRING*   sized_string;
+  char*           c_string;
+  int64_t         integer;
+  YR_STRING*      string;
+  YR_META*        meta;
 }
 /* Line 1529 of yacc.c.  */
-#line 187 "grammar.h"
+#line 183 "grammar.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
