@@ -22,70 +22,86 @@ static HANDLE hHeap;
 
 void yr_heap_alloc()
 {
-    hHeap = HeapCreate(0, 0x8000, 0);
+  hHeap = HeapCreate(0, 0x8000, 0);
 }
 
+
 void yr_heap_free()
 {
-    HeapDestroy(hHeap);
+  HeapDestroy(hHeap);
 }
 
+
 void* yr_malloc(size_t size)
 {
-    return (void*) HeapAlloc(hHeap, HEAP_ZERO_MEMORY, size);
+  return (void*) HeapAlloc(hHeap, HEAP_ZERO_MEMORY, size);
+}
+
+
+void* yr_realloc(void* ptr, size_t size)
+{
+  return (void*) HeapReAlloc(hHeap, HEAP_ZERO_MEMORY, ptr, size);
 }
 
 
 void yr_free(void* ptr)
 {
-    HeapFree(hHeap, 0, ptr);
+  HeapFree(hHeap, 0, ptr);
 }
 
 
 char* yr_strdup(const char *s)
 {
-    size_t len;
-    char *r;
-    
-    len = strlen(s);
-    
-    r = yr_malloc(len + 1);
-    
-    strcpy(r, s);
-    
-    return r;
+  size_t len = strlen(s);
+  char *r = yr_malloc(len + 1);
+  strcpy(r, s);
+  return r;
 }
 
 #else
 
 #include <stdlib.h>
 #include <string.h>
+#include <stdio.h>
+
+#ifdef DMALLOC
+#include <dmalloc.h>
+#endif
+
 
 void yr_heap_alloc()
 {
-    return;
+  return;
 }
 
+
 void yr_heap_free()
 {
-    return;
+  return;
 }
 
+
 void* yr_malloc(size_t size)
 {
-    return malloc(size);
+  return malloc(size);
+}
+
+
+void* yr_realloc(void* ptr, size_t size)
+{
+  return realloc(ptr, size);
 }
 
 
 void yr_free(void *ptr)
 {
-    free(ptr);
+  free(ptr);
 }
 
 
-char* yr_strdup(const char *s)
+char* yr_strdup(const char *str)
 {
-    return strdup(s);
+  return strdup(str);
 }
 
 #endif
\ No newline at end of file
