@@ -14,16 +14,42 @@ See the License for the specific language governing permissions and
 limitations under the License.
 */
 
-#ifndef _MEM_H 
+#ifndef _MEM_H
 #define _MEM_H
 
 #include <stdio.h>
 
+#include "config.h"
+
+#ifdef DMALLOC
+
+#define yr_malloc malloc
+#define yr_realloc realloc
+#define yr_free free
+#define yr_strdup strdup
+
+#include <dmalloc.h>
+
+#else
+
+void* yr_malloc(
+		size_t size);
+
+void* yr_realloc(
+		void* ptr,
+		size_t size);
+
+void yr_free(
+		void *ptr);
+
+char* yr_strdup(
+		const char *str);
+
+#endif
+
 void yr_heap_alloc();
+
 void yr_heap_free();
-void* yr_malloc(size_t size);
-void yr_free(void *ptr);
-char* yr_strdup(const char *s);
 
 #endif
 
