@@ -15,12 +15,13 @@ See the License for the specific language governing permissions and
 limitations under the License.
 */
 
-
 #ifndef _PROC_H
 #define _PROC_H
 
 #include "yara.h"
 
-int get_process_memory(int pid, MEMORY_BLOCK** first_block);
+int yr_process_get_memory(
+		int pid,
+		YR_MEMORY_BLOCK** first_block);
 
 #endif
